package com.example.veraxapplication.ui.article

import android.util.Log
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import coil.compose.rememberImagePainter
import coil.size.Scale
import com.example.veraxapplication.data.Article
import com.example.veraxapplication.data.Paragraph
import com.example.veraxapplication.ui.theme.Salmon

@Composable
fun AffichageLesArticles(articles : List<Article>){
    Column(modifier = Modifier.verticalScroll(rememberScrollState())){
        for(article in articles){
            AffichageUnArticle(e = article)
        }
    }
}

@Composable
fun AffichageUnArticle(e : Article){
    Column() {
        /*DisplayTitle(title = e.Title)
        DisplayHeader(author = e.Author, description = e.Description, lectureTime = e.LectureTime)
        DisplayImage(image = e.Image)
        DisplayContentArticle(content = e.Content)*/



        Text(text = e.Title, fontFamily = FontFamily.Serif, fontSize = 30.sp)

        Box(modifier = Modifier
            .fillMaxWidth()
            .border(width = 1.dp, color = Color.Black, shape = RoundedCornerShape(10.dp))
            .clip(RoundedCornerShape(10.dp))
            .background(Salmon)
            .padding(10.dp)) {
            Column () {
                Text(text = e.Author)
                Text(text = e.Description)
                Text(text = "Lecture Time: " + e.LectureTime + " minutes")
            }
        }
        Image(
            painter = rememberImagePainter(
                data = e.Image,
                builder = {
                    scale(Scale.FILL)
                }
            ),
            contentDescription = null,
            modifier = Modifier.size(250.dp),
        )


        Column {
            for(c in e.Content){
                Text(text = c.Content, fontSize = 15.sp, fontFamily = FontFamily.Serif, textAlign = TextAlign.Justify, modifier = Modifier.padding(10.dp))
            }
        }

    }
}

@Composable
fun DisplayImage(image: String) {
    Log.d("DisplayImage", "Chargement de l'image à partir de l'URL : $image")

    Log.d("DisplayImage", "Painter créé avec succès")

    Box(
        modifier = Modifier.fillMaxSize(),
        contentAlignment = Alignment.Center
    ) {
        Image(
            painter = rememberImagePainter(
                data = image,
                builder = {
                    scale(Scale.FILL)
                }
            ),
            contentDescription = null,
            modifier = Modifier.fillMaxSize(),
        )
    }
}



@Composable
fun DisplayHeader(author: String, description: String, lectureTime: String) {
    Box(modifier = Modifier
        .fillMaxWidth()
        .border(width = 1.dp, color = Color.Black, shape = RoundedCornerShape(10.dp))
        .clip(RoundedCornerShape(10.dp))
        .background(Salmon)
        .padding(10.dp)) {
        Column () {
            Text(text = author)
            Text(text = description)
            Text(text = "Lecture Time: " + lectureTime + " minutes")
        }
    }
}

@Composable
fun DisplayTitle(title: String) {
    Column(modifier = Modifier.fillMaxWidth(), horizontalAlignment = Alignment.CenterHorizontally){
        Text(text = title, fontFamily = FontFamily.Serif, fontSize = 30.sp)
    }
}

@Composable
fun DisplayContentArticle(content: List<Paragraph>) {
    Column {
        for(e in content){
            Text(text = e.Content, fontSize = 15.sp, fontFamily = FontFamily.Serif, textAlign = TextAlign.Justify, modifier = Modifier.padding(10.dp))
        }
    }
}